'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.Edition = undefined;

var _graphql = require('graphql');

var _mtgOmegaModelsSql = require('mtg-omega-models-sql');

var _single = require('./single');

var Edition = exports.Edition = new _graphql.GraphQLObjectType({
  name: 'edition',
  description: 'An edition of singles',
  fields: function () {
    function fields() {
      return {
        code: { type: _graphql.GraphQLString },
        name: {
          type: _graphql.GraphQLString,
          resolve: function () {
            function resolve(edition) {
              if (edition.i18n) {
                return edition.i18n[0].name;
              }

              return null;
            }

            return resolve;
          }()
        },

        singles: {
          type: new _graphql.GraphQLList(_single.Single),
          resolve: function () {
            function resolve(edition) {
              var query = { include: [] };

              if (edition.i18n.length === 1) {
                query.include.push({
                  model: _mtgOmegaModelsSql.SingleI18N,
                  as: 'i18n',
                  where: { language: edition.i18n[0].language }
                });
              }

              return edition.getSingles(query);
            }

            return resolve;
          }()
        }
      };
    }

    return fields;
  }()
});

exports['default'] = {
  editions: {
    type: new _graphql.GraphQLList(Edition),
    args: {
      code: { type: _graphql.GraphQLString },
      language: { type: _graphql.GraphQLString }
    },
    resolve: function () {
      function resolve(_, _ref) {
        var code = _ref.code,
            language = _ref.language;

        var query = {
          where: {},
          include: []
        };

        if (code) {
          query.where.code = code;
        }

        if (language) {
          query.include.push({
            model: _mtgOmegaModelsSql.EditionI18N,
            as: 'i18n',
            where: { language: language }
          });
        }

        return _mtgOmegaModelsSql.Edition.findAll(query);
      }

      return resolve;
    }()
  },

  edition: {
    type: Edition,
    args: {
      code: { type: new _graphql.GraphQLNonNull(_graphql.GraphQLString) },
      language: { type: _graphql.GraphQLString }
    },
    resolve: function () {
      function resolve(_, _ref2) {
        var code = _ref2.code,
            language = _ref2.language;

        var query = {
          where: { code: code },
          include: []
        };

        if (language) {
          query.include.push({
            model: _mtgOmegaModelsSql.EditionI18N,
            as: 'i18n',
            where: { language: language }
          });
        }

        return _mtgOmegaModelsSql.Edition.findOne(query);
      }

      return resolve;
    }()
  }
};